BullSpread

Struct BullSpread 

pub struct BullSpread { /* private fields */ }
Bull spread option payoff and profit.

Bull Spread = Long Call + Short Call

Implementations

Source

impl BullSpread

pub fn build(k_l: f64, k_s: f64, cost: f64) -> Result<Self, DigiFiError>

Creates a new BullSpread instance.

Input
  • k_l: Long call option strike price
  • k_s: Short call option strike price
  • cost: Initial option price (cost)
Errors
  • Returns an error if the short call strike price is smaller than the long call strike price.