GrangerCausalitySettings

Struct GrangerCausalitySettings 

pub struct GrangerCausalitySettings {
    pub pac_max_lag: Option<usize>,
    pub pac_ci: Option<f64>,
    pub x_max_lag: Option<usize>,
    pub t_test_cl: Option<ConfidenceLevel>,
    pub f_test_cl: Option<ConfidenceLevel>,
    pub return_nested_result: bool,
    pub return_parent_result: bool,
}
Settings of the Granger causality test.

Fields

pac_max_lag: Option<usize>

Maximum lag used in computing partial autocorrelations of Y

pac_ci: Option<f64>

Confidence interval for partial autocorrelation. This interval is used to find the order of the autoregressive model of Y such that the order is the lag after which the partial autocorrelations are all within the confidence interval.

Note: This confidence interval is used to compute the symmetrical critical values (i.e., ± critical values) which act as the cut-off points for the order of the autoregressive model of Y.

x_max_lag: Option<usize>

Maximum lag of X used in finding the optimal linear regression model of Y in terms of autoregressive terms of Y and X.

Note: If no maximum lag provided, the order of AR model of Y will be used as the maximum lag for autoregressive terms of X.

t_test_cl: Option<ConfidenceLevel>

Confidence level used to filter out the autoregressive terms of X

f_test_cl: Option<ConfidenceLevel>

Confidence level that should be used for the F-test (Note: if None is provided, then defaults to the ConfidenceLevel deafult value)

return_nested_result: bool

Whether to return the result of the nested model (i.e., AR model of Y)

return_parent_result: bool

Whether to return the result of the parent model (i.e., linear regression of Y in terms of autoregressive terms of Y and X)