KouJumpDiffusionProcess

Struct KouJumpDiffusionProcess 

pub struct KouJumpDiffusionProcess { /* private fields */ }
Model describes stock price with continuous movement that have rare large jumps, with the jump sizes following a double exponential distribution.

LaTeX Formula

  • dS_{t} = \mudt + \sigmadW_{t} + d(sum_{i=1}^{N(t)}(V_{i}-1))\n where V_{i} is i.i.d. non-negative random variables such that Y = log(V) is the assymetric double exponential distribution with density:\n
  • f_{Y}(y) = p*\eta_{1}e^{-\eta_{1}y}\mathbb{1}_{0\leq y} + (1-p)\eta_{2}*e^{\eta_{2}y}\mathbb{1}_{y<0}

Examples

use ndarray::Array1;
use digifi::utilities::TEST_ACCURACY;
use digifi::stochastic_processes::{StochasticProcessResult, StochasticProcess, KouJumpDiffusionProcess};

let n_paths: usize = 1_000;
let n_steps: usize = 200;

let kjd: KouJumpDiffusionProcess = KouJumpDiffusionProcess::build(0.2, 0.3, 0.5, 9.0, 5.0, 0.5, n_paths, n_steps, 1.0, 100.0).unwrap();
let sp_result: StochasticProcessResult = kjd.simulate().unwrap();

assert_eq!(sp_result.paths.len(), n_paths);
assert_eq!(sp_result.paths[0].len(), n_steps + 1);
assert_eq!(sp_result.expectations_path.clone().unwrap().len(), n_steps + 1);
assert_eq!(sp_result.variances_path.unwrap().len(), n_steps + 1);
assert!((sp_result.mean - sp_result.expectations_path.unwrap()[n_steps]).abs() < 20_000_000.0 * TEST_ACCURACY);

Implementations

Source

impl KouJumpDiffusionProcess

pub fn build( mu: f64, sigma: f64, lambda_n: f64, eta_1: f64, eta_2: f64, p: f64, n_paths: usize, n_steps: usize, t_f: f64, s_0: f64, ) -> Result<Self, DigiFiError>

Creates a new KouJumpDiffusionProcess instance.

Input
  • mu: Mean of base stochastic process (i.e., process without jumps)
  • sigma: Standard deviation of base process (i.e., process without jumps)
  • lambda_n: Rate of jumps
  • eta_1: Rate parameter of the positive jumps
  • eta_2: Rate parameter of the negative jumps
  • p: Probability of a jump up
  • n_paths: Number of paths to generate
  • n_steps: Number of steps
  • t_f: Final time step
  • s_0: Initial value of the stochastic process
Errors
  • Returns an error if the argument p is not in the range [0,1].