RSI

Struct RSI 

pub struct RSI {
    pub period: usize,
    pub oversold_band: f64,
    pub overbought_band: f64,
    pub u: Array1<f64>,
    pub d: Array1<f64>,
    pub u_smma: Array1<f64>,
    pub d_smma: Array1<f64>,
    pub rs: Array1<f64>,
    pub rsi: Array1<f64>,
    pub oversold: Array1<f64>,
    pub overbought: Array1<f64>,
}
Relative Strength Index (RSI) data.

Fields

period: usize

Size of the rolling window for the RSI

oversold_band: f64

Constant value of the oversold band

overbought_band: f64

Constant value of the overbought band

u: Array1<f64>

An array of upward price changes

d: Array1<f64>

An array of downward price changes

u_smma: Array1<f64>

An array of smoothed modified moving average readings of upward price changes

d_smma: Array1<f64>

An array of smoothed modified moving average readings of downward price changes

rs: Array1<f64>

An array relative strength factor readings

rsi: Array1<f64>

An array of RSI readings

oversold: Array1<f64>

An array of oversold band readings

overbought: Array1<f64>

An array of overbought band readings