pub struct Time(/* private fields */);Expand description
Struct that stores an array of time steps.
Examples
use ndarray::Array1;
use digifi::utilities::{TEST_ACCURACY, Time};
let time_1: Time = Time::new_from_range(0.0, 1.0, 0.2);
let time_2: Time = Time::new(Array1::from_vec(vec![0.0, 0.2, 0.4, 0.6, 0.8, 1.0]));
assert!((time_1.time_array() - time_2.time_array()).map(|v| v.abs() ).sum() < TEST_ACCURACY);Implementations
Sourceimpl Time
impl Time
Sourcepub fn new_from_range(initial_time: f64, final_time: f64, dt: f64) -> Self
pub fn new_from_range(initial_time: f64, final_time: f64, dt: f64) -> Self
Creates a range of time steps given the provided range definition.
Input
initial_time: Initial time setpfinal_time: Final time step (inclusive)dt: Difference between consequtive time steps.
Sourcepub fn time_array(&self) -> &Array1<f64>
pub fn time_array(&self) -> &Array1<f64>
Returns a reference to an array of time steps.
Note: This is a useful method for code readability.
Sourcepub fn time_array_mut(&mut self) -> &mut Array1<f64>
pub fn time_array_mut(&mut self) -> &mut Array1<f64>
Returns a mutable reference to an array of time steps.
Note: This is a useful method for code readability.